==> applet-service-1.0.2-20190125.034424-20-sources.jar: com/bizvane/appletservice/models/bo/ActivityAppletBO.java <==
package com.bizvane.appletservice.models.bo;

import java.util.Date;
import java.util.List;

public class ActivityAppletBO {
    private Integer points;
    private Date startTime;
    private Date endTime;
    private List<String> couponName;
    private String activityInfo;
    private String activityName;
    private Integer longTerm;

    @Override
    public String toString() {
        return "ActivityAppletBO{" +
                "points=" + points +
                ", startTime=" + startTime +
                ", endTime=" + endTime +
                ", couponName=" + couponName +
                ", activityInfo='" + activityInfo + '\'' +
                ", activityName='" + activityName + '\'' +
                ", longTerm=" + longTerm +
                '}';
    }

    public Integer getPoints() {
        return points;
    }

    public void setPoints(Integer points) {
        this.points = points;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public List<String> getCouponName() {
        return couponName;
    }

    public void setCouponName(List<String> couponName) {
        this.couponName = couponName;
    }

    public String getActivityInfo() {
        return activityInfo;
    }

    public void setActivityInfo(String activityInfo) {
        this.activityInfo = activityInfo;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public Integer getLongTerm() {
        return longTerm;
    }

    public void setLongTerm(Integer longTerm) {
        this.longTerm = longTerm;
    }
}

==> applet-service-1.0.2-20190729.030401-35-sources.jar: com/bizvane/appletservice/models/bo/ActivityAppletBO.java <==
package com.bizvane.appletservice.models.bo;

import java.util.Date;
import java.util.List;

public class ActivityAppletBO {
    private Integer points;
    private Date startTime;
    private Date endTime;
    private List<String> couponName;
    private String activityInfo;
    private String activityName;
    private Integer longTerm;
    private Integer activityInfoType;

    @Override
    public String toString() {
        return "ActivityAppletBO{" +
                "points=" + points +
                ", startTime=" + startTime +
                ", endTime=" + endTime +
                ", couponName=" + couponName +
                ", activityInfo='" + activityInfo + '\'' +
                ", activityName='" + activityName + '\'' +
                ", longTerm=" + longTerm +
                '}';
    }

    public Integer getPoints() {
        return points;
    }

    public void setPoints(Integer points) {
        this.points = points;
    }

    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public List<String> getCouponName() {
        return couponName;
    }

    public void setCouponName(List<String> couponName) {
        this.couponName = couponName;
    }

    public String getActivityInfo() {
        return activityInfo;
    }

    public void setActivityInfo(String activityInfo) {
        this.activityInfo = activityInfo;
    }

    public String getActivityName() {
        return activityName;
    }

    public void setActivityName(String activityName) {
        this.activityName = activityName;
    }

    public Integer getLongTerm() {
        return longTerm;
    }

    public void setLongTerm(Integer longTerm) {
        this.longTerm = longTerm;
    }

	public Integer getActivityInfoType() {
		return activityInfoType;
	}

	public void setActivityInfoType(Integer activityInfoType) {
		this.activityInfoType = activityInfoType;
	}
}
